paginatedRequest property

PaginatedSearchRequest<T>? paginatedRequest
final

Page-aware async request enabling infinite scroll (lazy loading).

When provided (instead of futureRequest) the dropdown loads the first page on open/search and appends the next page as the user scrolls near the bottom, stopping once a page returns fewer than pageSize items.

Implementation

final PaginatedSearchRequest<T>? paginatedRequest;