builder property
Optional fully custom transition. When provided it takes precedence over type, receiving the curved animation, the open direction and the child.
Implementation
final DropdownTransitionBuilder? builder;
Optional fully custom transition. When provided it takes precedence over type, receiving the curved animation, the open direction and the child.
final DropdownTransitionBuilder? builder;