floatingLabelGap property

double floatingLabelGap
final

Vertical gap reserved above the field for the floated label (the space between the floated label and the field below it).

Only applies when labelText/label is provided. Defaults to 16.

Implementation

final double floatingLabelGap;