floatingLabelStyle property
The style of the floating label once it has floated up.
Only applies when labelText is provided.
Implementation
final TextStyle? floatingLabelStyle;
The style of the floating label once it has floated up.
Only applies when labelText is provided.
final TextStyle? floatingLabelStyle;