labelStyle property
The style of the floating label in its resting (placeholder) position.
Only applies when labelText is provided.
Implementation
final TextStyle? labelStyle;
The style of the floating label in its resting (placeholder) position.
Only applies when labelText is provided.
final TextStyle? labelStyle;