DropdownAnimationType enum

Built-in open/close transitions for the CustomDropdown overlay.

All transitions are anchored to the dropdown field edge (they grow/scale/ slide from the side the overlay opens towards).

Inheritance
Available extensions

Values

size → const DropdownAnimationType

Reveal by growing the overlay height.

fade → const DropdownAnimationType

Fade the overlay in/out.

sizeFade → const DropdownAnimationType

Grow the height while fading (the historical default).

scale → const DropdownAnimationType

Scale the overlay up from the field edge.

scaleFade → const DropdownAnimationType

Scale up while fading.

slide → const DropdownAnimationType

Slide in from the field edge while fading.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DropdownAnimationType>
A constant List of the values in this enum, in order of their declaration.