labelText property
Optional Material-style floating label shown above/inside the closed field. When provided it acts as the field's placeholder while resting and floats up once the dropdown has a value or is open (see CustomDropdownDecoration.floatingLabelBehavior).
Implementation
final String? labelText;