searchRequestMinChars property
Minimum number of characters that must be typed before futureRequest is triggered. Below this length the request is not made and the base items are shown. Only applies to the search-request constructors.
Defaults to 0 (request on every change).
Implementation
final int searchRequestMinChars;