CustomDropdownDecoration class
Constructors
-
CustomDropdownDecoration({Color? closedFillColor, Color? expandedFillColor, List<
BoxShadow> ? closedShadow, List<BoxShadow> ? expandedShadow, Widget? closedSuffixIcon, Widget? expandedSuffixIcon, Widget? prefixIcon, BoxBorder? closedBorder, BorderRadius? closedBorderRadius, double? closedHeaderHeight, BoxBorder? closedErrorBorder, BorderRadius? closedErrorBorderRadius, BoxBorder? expandedBorder, BorderRadius? expandedBorderRadius, TextStyle? hintStyle, TextStyle? labelStyle, TextStyle? floatingLabelStyle, FloatingLabelBehavior floatingLabelBehavior = FloatingLabelBehavior.auto, double floatingLabelGap = 16, TextStyle? headerStyle, TextStyle? noResultFoundStyle, TextStyle? errorStyle, TextStyle? listItemStyle, ScrollbarThemeData? overlayScrollbarDecoration, SearchFieldDecoration? searchFieldDecoration, ListItemDecoration? listItemDecoration}) -
const
Properties
- closedBorder → BoxBorder?
-
Border for closed state of CustomDropdown.
final
- closedBorderRadius → BorderRadius?
-
Border radius for closed state of CustomDropdown.
final
- closedErrorBorder → BoxBorder?
-
Error border for closed state of CustomDropdown.
final
- closedErrorBorderRadius → BorderRadius?
-
Error border radius for closed state of CustomDropdown.
final
- closedFillColor → Color?
-
CustomDropdown field color (closed state).
final
- closedHeaderHeight → double?
-
Fixed height for the closed CustomDropdown header.
final
-
closedShadow
→ List<
BoxShadow> ? -
CustomDropdown box shadow (closed state).
final
- closedSuffixIcon → Widget?
-
Suffix icon for closed state of CustomDropdown.
final
- errorStyle → TextStyle?
-
The style to use for the string returning from CustomDropdown.validator.
final
- expandedBorder → BoxBorder?
-
Border for opened/expanded state of CustomDropdown.
final
- expandedBorderRadius → BorderRadius?
-
Border radius for opened/expanded state of CustomDropdown.
final
- expandedFillColor → Color?
-
CustomDropdown overlay color (opened/expanded state).
final
-
expandedShadow
→ List<
BoxShadow> ? -
CustomDropdown box shadow (opened/expanded state).
final
- expandedSuffixIcon → Widget?
-
Suffix icon for opened/expanded state of CustomDropdown.
final
- floatingLabelBehavior → FloatingLabelBehavior
-
Controls when the floating label floats up.
Only applies when
labelTextis provided. Defaults to FloatingLabelBehavior.auto (floats when the dropdown has a value or is open).final - floatingLabelGap → double
-
Vertical gap reserved above the field for the floated label (the space
between the floated label and the field below it).
final
- floatingLabelStyle → TextStyle?
-
The style of the floating label once it has floated up.
Only applies when
labelTextis provided.final - hashCode → int
-
The hash code for this object.
no setterinherited
- headerStyle → TextStyle?
-
The style to use for the CustomDropdown header text.
final
- hintStyle → TextStyle?
-
The style to use for the CustomDropdown header hint.
final
- labelStyle → TextStyle?
-
The style of the floating label in its resting (placeholder) position.
Only applies when
labelTextis provided.final - listItemDecoration → ListItemDecoration?
-
CustomDropdown list item decoration.
final
- listItemStyle → TextStyle?
-
The style to use for the CustomDropdown list item text.
final
- noResultFoundStyle → TextStyle?
-
The style to use for the CustomDropdown no result found area.
final
- overlayScrollbarDecoration → ScrollbarThemeData?
-
CustomDropdown scrollbar decoration (opened/expanded state).
final
- prefixIcon → Widget?
-
CustomDropdown header prefix icon.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchFieldDecoration → SearchFieldDecoration?
-
CustomDropdown search field decoration.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited