closedHeaderHeight property
Fixed height for the closed CustomDropdown header.
When set, the closed field uses this height and its content is centered vertically. When null, the height is driven by the header padding.
Implementation
final double? closedHeaderHeight;